@@ -223,12 +223,31 @@ def textsortchrs(txts: str, alph: list = None):
             del once, maxi, space, asci, punct, uni, digi, pri
         except Exception as e:
             raise e
+
+def fixedsaving(text: str, path: str, name: str):
+    """Saving text that has been fixed to a new file."""
+    
+    if os.path.isfile(text):
+        if text.rpartition('.')[2] == 'txt':
+            with open(text) as rd:
+                text = rd.read()
+        else:
+            raise Exception('Cannot read non-.txt file!!!')
+    
+    if os.path.isdir(path):
+        path = os.path.join(path, name := name if name.rpartition('.')[2] == 'txt' else f'{name}.txt')
+        Fixstr(text).savefix(path)
+        print(f'file [{path}] has been created and saved!')
+        del path
+    else:
+        raise Exception('Path need to be a directory!')
             
 def main():
     parser = argparse.ArgumentParser(prog = 'DecAn',description = 'Analyze and Deconstruct words')
     group = parser.add_mutually_exclusive_group()
     group.add_argument('-d', '--deconstruct', type = str, nargs = 3, help = 'Save deconstruct as json file')
     group.add_argument('-c', '--construct', type = str, help = 'Construct back the deconstruct in json file')
+    group.add_argument('-f', '--fix_saved', type = str, nargs = 3, help = 'Fixing text and saved to a new file.')
     parser.add_argument('-a', '--analyze', type = str, help = 'Analyzing chars in a text')
     parser.add_argument('-s', '--search', type = str, action = 'extend', nargs = '+', help = 'Search list [only use after "-a"]')
     args = parser.parse_args()
@@ -241,6 +260,8 @@ def main():
         deconstruct(args.deconstruct[0], args.deconstruct[1], args.deconstruct[2])
     elif args.construct:
         print(construct(args.construct))
+    elif args.fix_saved:
+        fixedsaving(args.fix_saved[0], args.fix_saved[1], args.fix_saved[2])    
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
